#!/bin/sh
# This script uninstalls yumwat on Fedora 18 and 19.
# Not tested on other platforms.
# Requires root privs.

# Uninstall config file
rm /etc/yum/pluginconf.d/yumwat.conf

# Uninstall plugin and generated bytecode
rm /usr/lib/yum-plugins/yumwat.{py,pyc}
